ryvencore.Script module - ryvencore v0.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Toggle table of contents sidebar

# ryvencore.Script module

class Script(session, title: Optional[str] = None, load_data: Optional[dict] = None, create_default_logs=True)

  Bases: `ryvencore.Base.Base`

  A Script consists of a Flow, the corresponding FlowView, a variables manager and a logger.

  load_flow()
  data() → dict

    converts the object to a JSON compatible dict for serialization